/**
 * This file contains 4-operator MIDI instrument defenitions for use with the OPL2 Audio Board library. These are a more
 * generic set of instruments. This file contains the melodic instrments only.
 *
 * Instrument definition is based on Adlib instrument bank format.
 *  0 - Rhythm mode drum channel
 *		Drum channels are predefined by the YM3812 and cannot be redefined. Regular instruments have their channel set
 *		to 0x00 and can be assigned to any channel by the setInstrument function. Rhythm mode instruments can only be
 *		used when rhythm mode is active (see OPL2.setPercussion).
 *
 *  1 - Channel c, operator 1, register 0x20
 *		Tremolo(1) | Vibrato(1) | Sustain(1) | KSR(1) | Frequency multiplier (4)
 *
 *  2 - Channel c, operator 1, register 0x40
 *		Key scale level(2) | Output level(6)
 *
 *  3 - Channel c, operator 1, register 0x60
 *		Attack(4) | Decay(4)
 *
 *  4 - Channel c, operator 1, register 0x80
 *		Sustain(4) | Release(4)
 *
 *  5 - Channel c, operator 1, register 0xE0
 *		Undefined(5) | Waveform(3)
 *
 *  6 - Channel c, register 0xC0
 *		Undefined(4) | Modulation feedback factor(3) | Synth type(1)
 *
 *  7 - Channel c, operator 2, register 0x20
 *  8 - Channel c, operator 2, register 0x40
 *  9 - Channel c, operator 2, register 0x60
 * 10 - Channel c, operator 2, register 0x80
 * 11 - Channel c, operator 2, register 0xE0
 */

#ifndef _MIDI_INST4OP_H_
	#define _MIDI_INST4OP_H_

	const unsigned char INSTRUMENT_PIANO1[24]   PROGMEM = { 0x00, 0x23, 0x15, 0xFD, 0x7C, 0x03, 0x00, 0x01, 0x08, 0x84, 0xF5, 0x00, 0x00, 0x03, 0x5D, 0xF2, 0x35, 0x00, 0x01, 0x01, 0x08, 0xF4, 0xF5, 0x04 };
	const unsigned char INSTRUMENT_PIANO2[24]   PROGMEM = { 0x00, 0x03, 0x7D, 0xF3, 0xF5, 0x00, 0x00, 0x01, 0x08, 0xF3, 0xF5, 0x04, 0x00, 0x03, 0x55, 0xF2, 0xF5, 0x00, 0x01, 0x01, 0x08, 0xF2, 0xF5, 0x04 };
	const unsigned char INSTRUMENT_PIANO3[24]   PROGMEM = { 0x00, 0x03, 0x4D, 0xFB, 0x55, 0x04, 0x00, 0x01, 0x08, 0xF3, 0xC5, 0x04, 0x00, 0x03, 0xCE, 0xF3, 0x55, 0x00, 0x01, 0x01, 0x08, 0xF3, 0xD5, 0x04 };
	const unsigned char INSTRUMENT_HONKTONK[24] PROGMEM = { 0x00, 0x03, 0xD7, 0xF3, 0xF5, 0x04, 0x00, 0x01, 0x08, 0xF2, 0xF5, 0x04, 0x00, 0x03, 0xD5, 0xF3, 0xF5, 0x00, 0x01, 0x01, 0x08, 0xF3, 0xF5, 0x04 };
	const unsigned char INSTRUMENT_EP1[24]      PROGMEM = { 0x00, 0x16, 0x57, 0xFF, 0x8A, 0x00, 0x0C, 0x01, 0x08, 0xF3, 0x66, 0x00, 0x00, 0x0B, 0x2B, 0xE5, 0xB5, 0x00, 0x01, 0x81, 0x08, 0xE2, 0x86, 0x00 };
	const unsigned char INSTRUMENT_EP2[24]      PROGMEM = { 0x00, 0x0A, 0x5F, 0xF4, 0x87, 0x00, 0x00, 0x01, 0x08, 0xF4, 0x86, 0x00, 0x00, 0x03, 0xCC, 0xF2, 0x86, 0x00, 0x01, 0x01, 0x08, 0xE2, 0x86, 0x00 };
	const unsigned char INSTRUMENT_HARPSIC[24]  PROGMEM = { 0x00, 0x22, 0xD1, 0xE3, 0x79, 0x04, 0x04, 0x01, 0x88, 0xF3, 0xA7, 0x04, 0x00, 0x22, 0x96, 0xF2, 0x79, 0x04, 0x01, 0x01, 0x08, 0xF3, 0xA7, 0x04 };
	const unsigned char INSTRUMENT_CLAVIC[24]   PROGMEM = { 0x00, 0x22, 0x9C, 0xF4, 0x19, 0x05, 0x00, 0x01, 0x08, 0xF3, 0xA6, 0x05, 0x00, 0x22, 0x97, 0xF4, 0x19, 0x04, 0x01, 0x01, 0x08, 0xF3, 0xE6, 0x04 };
	const unsigned char INSTRUMENT_CELESTA[24]  PROGMEM = { 0x00, 0x1B, 0x5A, 0xF4, 0xF6, 0x00, 0x00, 0x19, 0x09, 0xE3, 0xA2, 0x00, 0x00, 0x1A, 0x57, 0xF3, 0xB2, 0x00, 0x01, 0x11, 0x08, 0xF2, 0xA3, 0x00 };
	const unsigned char INSTRUMENT_GLOCK[24]    PROGMEM = { 0x00, 0x1B, 0x5A, 0xD6, 0x53, 0x00, 0x00, 0x17, 0x0A, 0xF3, 0x53, 0x00, 0x00, 0x1A, 0x49, 0xD1, 0x52, 0x00, 0x01, 0x11, 0x08, 0xF3, 0x52, 0x00 };
	const unsigned char INSTRUMENT_MUSICBOX[24] PROGMEM = { 0x00, 0x1B, 0x5A, 0xF6, 0xF6, 0x00, 0x00, 0x14, 0x08, 0x63, 0xA3, 0x00, 0x00, 0x1B, 0x52, 0xD3, 0xB2, 0x00, 0x01, 0x11, 0x08, 0xF2, 0xA3, 0x00 };
	const unsigned char INSTRUMENT_VIBES[24]    PROGMEM = { 0x00, 0x8B, 0x5A, 0xD7, 0x15, 0x00, 0x00, 0x84, 0x08, 0xF1, 0x95, 0x00, 0x00, 0x9B, 0x49, 0xDC, 0x25, 0x00, 0x01, 0x81, 0x08, 0xD2, 0xB5, 0x00 };
	const unsigned char INSTRUMENT_MARIMBA[24]  PROGMEM = { 0x00, 0x08, 0xC0, 0xFD, 0x56, 0x00, 0x00, 0x01, 0x08, 0xF6, 0x68, 0x00, 0x00, 0x95, 0x40, 0xFE, 0x27, 0x00, 0x01, 0x81, 0x08, 0xF0, 0x05, 0x00 };
	const unsigned char INSTRUMENT_XYLO[24]     PROGMEM = { 0x00, 0x08, 0xC0, 0xFA, 0x56, 0x00, 0x00, 0x03, 0x08, 0xF8, 0x66, 0x00, 0x00, 0x97, 0x40, 0xDF, 0x26, 0x00, 0x01, 0x81, 0x08, 0xF8, 0x06, 0x00 };
	const unsigned char INSTRUMENT_TUBEBELL[24] PROGMEM = { 0x00, 0x03, 0x95, 0xF3, 0x33, 0x00, 0x00, 0x00, 0x88, 0xF3, 0x23, 0x00, 0x00, 0x03, 0x8C, 0xF4, 0x23, 0x00, 0x01, 0x00, 0x88, 0xF3, 0x03, 0x00 };
	const unsigned char INSTRUMENT_SANTUR[24]   PROGMEM = { 0x00, 0x01, 0x8B, 0xA7, 0xF9, 0x06, 0x00, 0x00, 0x08, 0x94, 0x36, 0x05, 0x00, 0x02, 0x18, 0xF6, 0x79, 0x04, 0x01, 0x81, 0x88, 0xF4, 0x55, 0x04 };
	const unsigned char INSTRUMENT_ORGAN1[24]   PROGMEM = { 0x00, 0x24, 0x40, 0xFD, 0xFD, 0x00, 0x00, 0x24, 0x0A, 0xFB, 0x0E, 0x00, 0x00, 0x20, 0x95, 0xFB, 0x0E, 0x00, 0x01, 0x20, 0x08, 0xF6, 0x0E, 0x00 };
	const unsigned char INSTRUMENT_ORGAN2[24]   PROGMEM = { 0x00, 0x04, 0x17, 0xFE, 0xB7, 0x00, 0x00, 0x24, 0x08, 0xF7, 0x67, 0x00, 0x00, 0x20, 0x14, 0xF9, 0x06, 0x00, 0x01, 0xA0, 0x08, 0xF6, 0x07, 0x00 };
	const unsigned char INSTRUMENT_ORGAN3[24]   PROGMEM = { 0x00, 0xA2, 0x1E, 0xB9, 0x36, 0x00, 0x00, 0x20, 0x08, 0xA9, 0x0E, 0x00, 0x00, 0xB4, 0x1A, 0x79, 0x51, 0x04, 0x01, 0x20, 0x08, 0x77, 0x4C, 0x00 };
	const unsigned char INSTRUMENT_PIPEORG[24]  PROGMEM = { 0x00, 0x25, 0x23, 0x74, 0x11, 0x00, 0x02, 0xA1, 0x08, 0x60, 0x05, 0x00, 0x00, 0xB0, 0xD3, 0x74, 0x12, 0x04, 0x01, 0xB0, 0x08, 0x60, 0x05, 0x01 };
	const unsigned char INSTRUMENT_REEDORG[24]  PROGMEM = { 0x00, 0x22, 0x24, 0x76, 0x06, 0x04, 0x00, 0x21, 0x48, 0x76, 0x06, 0x04, 0x00, 0x20, 0x21, 0x76, 0x06, 0x00, 0x01, 0x21, 0x08, 0x66, 0x06, 0x02 };
	const unsigned char INSTRUMENT_ACORDIAN[24] PROGMEM = { 0x00, 0x22, 0x1B, 0x76, 0x07, 0x00, 0x00, 0x21, 0x08, 0x76, 0x07, 0x04, 0x00, 0x21, 0x19, 0x76, 0x07, 0x00, 0x01, 0x21, 0x08, 0x66, 0x07, 0x02 };
	const unsigned char INSTRUMENT_HARMONIC[24] PROGMEM = { 0x00, 0x21, 0x20, 0x93, 0x09, 0x04, 0x00, 0x21, 0x08, 0x73, 0x09, 0x04, 0x00, 0x21, 0x27, 0x76, 0x09, 0x04, 0x01, 0x21, 0x08, 0x76, 0x09, 0x04 };
	const unsigned char INSTRUMENT_BANDNEON[24] PROGMEM = { 0x00, 0x21, 0x1E, 0x76, 0x09, 0x04, 0x00, 0x21, 0x08, 0x66, 0x19, 0x05, 0x00, 0x21, 0x22, 0x76, 0x29, 0x04, 0x01, 0x21, 0x08, 0x66, 0x19, 0x04 };
	const unsigned char INSTRUMENT_NYLONGT[24]  PROGMEM = { 0x00, 0x1B, 0x4C, 0xFE, 0xFE, 0x04, 0x00, 0x11, 0x08, 0xF2, 0xE3, 0x00, 0x00, 0x31, 0x4C, 0xF2, 0x45, 0x04, 0x01, 0x11, 0x08, 0xF2, 0xF4, 0x00 };
	const unsigned char INSTRUMENT_STEELGT[24]  PROGMEM = { 0x00, 0x30, 0x08, 0xF2, 0x49, 0x02, 0x01, 0x05, 0x0B, 0xFE, 0x43, 0x01, 0x00, 0x01, 0x08, 0xF2, 0xE7, 0x01, 0x01, 0x00, 0x08, 0xF3, 0x9D, 0x02 };
	const unsigned char INSTRUMENT_JAZZGT[24]   PROGMEM = { 0x00, 0x34, 0x0D, 0xF2, 0x49, 0x00, 0x01, 0x04, 0x16, 0xFD, 0x43, 0x00, 0x00, 0x01, 0x08, 0xF2, 0xE7, 0x00, 0x01, 0x01, 0x0C, 0xF3, 0x9D, 0x00 };
	const unsigned char INSTRUMENT_CLEANGT[24]  PROGMEM = { 0x00, 0x03, 0x00, 0xFB, 0x49, 0x06, 0x09, 0x23, 0x00, 0xFC, 0x64, 0x00, 0x00, 0x01, 0x08, 0xF4, 0xC4, 0x02, 0x01, 0x01, 0x08, 0xF6, 0xC4, 0x06 };
	const unsigned char INSTRUMENT_MUTEGT[24]   PROGMEM = { 0x00, 0x01, 0x06, 0xF6, 0x27, 0x05, 0x00, 0x01, 0x0D, 0xF3, 0xE7, 0x01, 0x00, 0x02, 0x05, 0xFA, 0x96, 0x04, 0x01, 0x01, 0x08, 0x65, 0x9B, 0x04 };
	const unsigned char INSTRUMENT_OVERDGT[24]  PROGMEM = { 0x00, 0x21, 0xC1, 0xF2, 0x13, 0x00, 0x00, 0x21, 0x48, 0xF3, 0x16, 0x04, 0x00, 0x21, 0x03, 0x97, 0xAE, 0x03, 0x01, 0x21, 0x08, 0x96, 0x26, 0x05 };
	const unsigned char INSTRUMENT_DISTGT[24]   PROGMEM = { 0x00, 0x21, 0xC1, 0xF2, 0x16, 0x00, 0x00, 0x21, 0x08, 0xF2, 0x16, 0x04, 0x00, 0x21, 0x03, 0xC7, 0x46, 0x03, 0x01, 0x20, 0x08, 0x90, 0x16, 0x03 };
	const unsigned char INSTRUMENT_GTHARMS[24]  PROGMEM = { 0x00, 0x0B, 0x40, 0x65, 0x1A, 0x00, 0x0C, 0x01, 0x48, 0xF2, 0x3E, 0x03, 0x00, 0x05, 0x00, 0xE2, 0x1A, 0x02, 0x01, 0x0A, 0x49, 0x54, 0x1A, 0x01 };
	const unsigned char INSTRUMENT_ACOUBASS[24] PROGMEM = { 0x00, 0x21, 0x12, 0xE4, 0x15, 0x00, 0x00, 0x21, 0x08, 0xD3, 0xA6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
	const unsigned char INSTRUMENT_FINGBASS[24] PROGMEM = { 0x00, 0x21, 0x08, 0xF2, 0x49, 0x04, 0x01, 0x01, 0x0B, 0xF2, 0x97, 0x05, 0x00, 0x01, 0x09, 0xF6, 0xE7, 0x01, 0x01, 0x01, 0x08, 0xF3, 0x9D, 0x04 };
	const unsigned char INSTRUMENT_PICKBASS[24] PROGMEM = { 0x00, 0x21, 0x08, 0xF2, 0x49, 0x04, 0x01, 0x01, 0x08, 0xF2, 0x97, 0x05, 0x00, 0x01, 0x08, 0xF6, 0xE7, 0x01, 0x01, 0x01, 0x08, 0xF3, 0x9D, 0x04 };
	const unsigned char INSTRUMENT_FRETLESS[24] PROGMEM = { 0x00, 0x01, 0xC8, 0xF2, 0x6A, 0x00, 0x09, 0x01, 0x08, 0xC4, 0x97, 0x00, 0x00, 0x01, 0x11, 0x91, 0xE7, 0x00, 0x01, 0x01, 0x08, 0xF2, 0x6D, 0x00 };
	const unsigned char INSTRUMENT_SLAPBAS1[24] PROGMEM = { 0x00, 0x01, 0x06, 0xFD, 0x49, 0x06, 0x01, 0x0B, 0x08, 0xFA, 0x87, 0x04, 0x00, 0x01, 0x08, 0xF3, 0xB7, 0x04, 0x01, 0x01, 0x08, 0xF3, 0x9D, 0x04 };
	const unsigned char INSTRUMENT_SLAPBAS2[24] PROGMEM = { 0x00, 0x26, 0x24, 0xF6, 0x87, 0x04, 0x00, 0x21, 0x08, 0xF2, 0xF7, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
	const unsigned char INSTRUMENT_SYNBASS1[24] PROGMEM = { 0x00, 0x21, 0x08, 0xF5, 0x47, 0x00, 0x00, 0x01, 0x48, 0xF2, 0xF7, 0x00, 0x00, 0x21, 0x07, 0xF5, 0x47, 0x00, 0x09, 0x01, 0x48, 0xF2, 0xF7, 0x00 };
	const unsigned char INSTRUMENT_SYNBASS2[24] PROGMEM = { 0x00, 0xC1, 0x08, 0xF2, 0x48, 0x00, 0x01, 0x01, 0x21, 0xF2, 0x97, 0x00, 0x00, 0x01, 0x0A, 0xF2, 0x97, 0x00, 0x00, 0x01, 0x08, 0xF2, 0x77, 0x00 };
	const unsigned char INSTRUMENT_VIOLIN[24]   PROGMEM = { 0x00, 0x22, 0xCA, 0xB4, 0x26, 0x04, 0x0C, 0x21, 0x11, 0x44, 0x06, 0x04, 0x00, 0x22, 0xCC, 0x89, 0x16, 0x04, 0x01, 0x01, 0x10, 0x5D, 0x06, 0x04 };
	const unsigned char INSTRUMENT_VIOLA[24]    PROGMEM = { 0x00, 0x24, 0xCB, 0x88, 0x26, 0x04, 0x0C, 0x21, 0x10, 0x66, 0x16, 0x04, 0x00, 0x34, 0xC4, 0x86, 0x66, 0x04, 0x01, 0x21, 0x10, 0x66, 0x06, 0x04 };
	const unsigned char INSTRUMENT_CELLO[24]    PROGMEM = { 0x00, 0x22, 0xCB, 0x72, 0x46, 0x04, 0x06, 0x01, 0x1C, 0x5F, 0x86, 0x04, 0x00, 0x22, 0xCD, 0x76, 0x36, 0x04, 0x01, 0x21, 0x08, 0x54, 0x06, 0x04 };
	const unsigned char INSTRUMENT_CONTRAB[24]  PROGMEM = { 0x00, 0x22, 0xFF, 0x86, 0x06, 0x04, 0x06, 0x01, 0x08, 0x6F, 0x08, 0x04, 0x00, 0x22, 0xD2, 0x74, 0x16, 0x04, 0x01, 0x21, 0x08, 0x54, 0x06, 0x04 };
	const unsigned char INSTRUMENT_TREMSTR[24]  PROGMEM = { 0x00, 0x60, 0x00, 0x68, 0x04, 0x02, 0x01, 0x61, 0x09, 0x53, 0x45, 0x03, 0x00, 0x61, 0x11, 0x54, 0x54, 0x01, 0x01, 0x60, 0x08, 0x78, 0x35, 0x03 };
	const unsigned char INSTRUMENT_PIZZ[24]     PROGMEM = { 0x00, 0x00, 0x07, 0xF9, 0xF1, 0x03, 0x06, 0x00, 0x08, 0xF6, 0x34, 0x02, 0x00, 0x00, 0x0C, 0x89, 0xF1, 0x03, 0x01, 0x00, 0x08, 0xB5, 0x34, 0x02 };
	const unsigned char INSTRUMENT_HARP[24]     PROGMEM = { 0x00, 0x12, 0xD0, 0xB5, 0x23, 0x04, 0x00, 0x01, 0x17, 0xC3, 0xE3, 0x00, 0x00, 0x12, 0xD9, 0xE5, 0x15, 0x04, 0x01, 0x11, 0x08, 0xA2, 0xF3, 0x00 };
	const unsigned char INSTRUMENT_TIMPANI[24]  PROGMEM = { 0x00, 0x11, 0xD0, 0xE4, 0xE4, 0x01, 0x00, 0x10, 0x08, 0xD3, 0xF4, 0x00, 0x00, 0x14, 0x14, 0xF6, 0xF4, 0x02, 0x01, 0x10, 0x08, 0xF3, 0xF4, 0x02 };
	const unsigned char INSTRUMENT_STRINGS[24]  PROGMEM = { 0x00, 0x21, 0x1B, 0xA9, 0x23, 0x00, 0x0E, 0x21, 0xC8, 0x63, 0x25, 0x04, 0x00, 0x21, 0x22, 0xA9, 0x23, 0x00, 0x01, 0x21, 0x48, 0x43, 0x24, 0x04 };
	const unsigned char INSTRUMENT_SLOWSTR[24]  PROGMEM = { 0x00, 0x21, 0x1F, 0xA9, 0x23, 0x00, 0x0E, 0x21, 0xC8, 0x33, 0x15, 0x04, 0x00, 0x21, 0x23, 0x60, 0x23, 0x00, 0x01, 0x21, 0x88, 0x33, 0x25, 0x04 };
	const unsigned char INSTRUMENT_SYNSTR1[24]  PROGMEM = { 0x00, 0x20, 0x08, 0x52, 0xB6, 0x02, 0x01, 0x01, 0x0C, 0x50, 0x15, 0x01, 0x00, 0x21, 0x09, 0x44, 0x04, 0x01, 0x01, 0x20, 0x51, 0x41, 0x27, 0x02 };
	const unsigned char INSTRUMENT_SYNSTR2[24]  PROGMEM = { 0x00, 0x22, 0x48, 0x51, 0xA4, 0x04, 0x01, 0x01, 0xC2, 0x31, 0xF4, 0x01, 0x00, 0x21, 0x08, 0x70, 0xF4, 0x01, 0x01, 0x21, 0x48, 0x34, 0x74, 0x04 };
	const unsigned char INSTRUMENT_CHOIR[24]    PROGMEM = { 0x00, 0x21, 0x10, 0x61, 0x04, 0x00, 0x0A, 0x21, 0x08, 0x66, 0x45, 0x04, 0x00, 0x20, 0x1C, 0x63, 0x05, 0x00, 0x01, 0x21, 0x08, 0x63, 0x04, 0x00 };
	const unsigned char INSTRUMENT_OOHS[24]     PROGMEM = { 0x00, 0x21, 0x16, 0xA6, 0x66, 0x00, 0x00, 0x21, 0x08, 0x77, 0x06, 0x00, 0x00, 0x20, 0xD8, 0x66, 0x36, 0x00, 0x01, 0x21, 0x08, 0x68, 0x06, 0x00 };
	const unsigned char INSTRUMENT_SYNVOX[24]   PROGMEM = { 0x00, 0x21, 0x12, 0x75, 0x66, 0x00, 0x00, 0x21, 0x08, 0x67, 0x06, 0x00, 0x00, 0x21, 0x2D, 0x62, 0x36, 0x00, 0x01, 0x21, 0x08, 0x68, 0x06, 0x00 };
	const unsigned char INSTRUMENT_ORCHIT[24]   PROGMEM = { 0x00, 0x02, 0x0E, 0x76, 0x34, 0x00, 0x00, 0x01, 0x08, 0x64, 0x35, 0x04, 0x00, 0x01, 0x2D, 0x66, 0x35, 0x04, 0x01, 0x00, 0x08, 0x63, 0x04, 0x00 };
	const unsigned char INSTRUMENT_TRUMPET[24]  PROGMEM = { 0x00, 0x21, 0x23, 0x72, 0x9B, 0x01, 0x00, 0x21, 0x08, 0x72, 0x3B, 0x04, 0x00, 0x21, 0x23, 0x82, 0x9B, 0x01, 0x01, 0x21, 0x08, 0x92, 0x3B, 0x04 };
	const unsigned char INSTRUMENT_TROMBONE[24] PROGMEM = { 0x00, 0x21, 0x23, 0x63, 0x9B, 0x01, 0x00, 0x21, 0x08, 0x62, 0x3B, 0x04, 0x00, 0x21, 0x21, 0x73, 0x9B, 0x01, 0x01, 0x21, 0x08, 0x82, 0x3B, 0x04 };
	const unsigned char INSTRUMENT_TUBA[24]     PROGMEM = { 0x00, 0x01, 0x14, 0x62, 0x0B, 0x05, 0x06, 0x01, 0x08, 0xE6, 0x2B, 0x05, 0x00, 0x21, 0x13, 0x55, 0x1B, 0x04, 0x01, 0x22, 0x08, 0x72, 0x2B, 0x00 };
	const unsigned char INSTRUMENT_MUTETRP[24]  PROGMEM = { 0x00, 0x01, 0x11, 0x60, 0xFB, 0x05, 0x00, 0x21, 0x18, 0x62, 0x7B, 0x00, 0x00, 0x01, 0x10, 0x60, 0x3B, 0x05, 0x01, 0x21, 0x17, 0x62, 0x7B, 0x00 };
	const unsigned char INSTRUMENT_FRHORN[24]   PROGMEM = { 0x00, 0x21, 0x23, 0x41, 0x94, 0x00, 0x0E, 0x21, 0x08, 0x81, 0xF6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
	const unsigned char INSTRUMENT_BRASS1[24]   PROGMEM = { 0x00, 0x22, 0x4C, 0x75, 0x37, 0x01, 0x00, 0x61, 0x48, 0xF1, 0xB7, 0x05, 0x00, 0x21, 0x4D, 0x56, 0x07, 0x05, 0x01, 0x20, 0x08, 0x72, 0x17, 0x02 };
	const unsigned char INSTRUMENT_SYNBRAS1[24] PROGMEM = { 0x00, 0x21, 0x04, 0x82, 0xCB, 0x01, 0x06, 0x21, 0x09, 0x71, 0x2B, 0x01, 0x00, 0x21, 0x11, 0x75, 0x8B, 0x00, 0x01, 0x21, 0x08, 0x80, 0x3B, 0x00 };
	const unsigned char INSTRUMENT_SYNBRAS2[24] PROGMEM = { 0x00, 0x21, 0x83, 0x84, 0x3B, 0x01, 0x06, 0x21, 0x4D, 0xA2, 0x3B, 0x00, 0x00, 0x21, 0x0E, 0x74, 0x7B, 0x00, 0x01, 0x21, 0x08, 0x73, 0x3B, 0x00 };
	const unsigned char INSTRUMENT_SOPSAX[24]   PROGMEM = { 0x00, 0x01, 0x15, 0x70, 0xE7, 0x05, 0x00, 0x02, 0x08, 0x70, 0xE8, 0x00, 0x00, 0x01, 0x42, 0x70, 0xF8, 0x07, 0x01, 0x00, 0x08, 0x70, 0xE8, 0x02 };
	const unsigned char INSTRUMENT_ALTOSAX[24]  PROGMEM = { 0x00, 0x01, 0x13, 0x70, 0xE9, 0x05, 0x00, 0x01, 0x08, 0x70, 0xE9, 0x00, 0x00, 0x01, 0x47, 0x70, 0xE9, 0x07, 0x01, 0x40, 0x48, 0x70, 0xE9, 0x02 };
	const unsigned char INSTRUMENT_TENSAX[24]   PROGMEM = { 0x00, 0x01, 0x15, 0x70, 0xEB, 0x05, 0x00, 0x01, 0x08, 0x70, 0xEA, 0x00, 0x00, 0x01, 0x09, 0x70, 0xEB, 0x07, 0x01, 0x40, 0x08, 0x70, 0xEB, 0x02 };
	const unsigned char INSTRUMENT_BARISAX[24]  PROGMEM = { 0x00, 0x01, 0x11, 0xA4, 0xBB, 0x00, 0x00, 0x04, 0x0D, 0x67, 0x6A, 0x00, 0x00, 0x01, 0x0C, 0xD0, 0xEB, 0x01, 0x01, 0x02, 0x08, 0x80, 0xEB, 0x02 };
	const unsigned char INSTRUMENT_OBOE[24]     PROGMEM = { 0x00, 0x11, 0x17, 0x70, 0x29, 0x00, 0x00, 0x34, 0x08, 0x61, 0x29, 0x00, 0x00, 0x31, 0xFF, 0x60, 0x09, 0x00, 0x01, 0x34, 0x7F, 0x60, 0x09, 0x02 };
	const unsigned char INSTRUMENT_ENGLHORN[24] PROGMEM = { 0x00, 0x01, 0x11, 0xF0, 0x29, 0x00, 0x00, 0x24, 0x08, 0x80, 0x09, 0x00, 0x00, 0x31, 0xDA, 0x80, 0x09, 0x00, 0x01, 0x24, 0x08, 0x80, 0x09, 0x00 };
	const unsigned char INSTRUMENT_BASSOON[24]  PROGMEM = { 0x00, 0x01, 0x13, 0x60, 0x22, 0x00, 0x00, 0x24, 0x0C, 0x80, 0x09, 0x00, 0x00, 0x31, 0x86, 0x80, 0x05, 0x00, 0x01, 0x24, 0x18, 0x80, 0x09, 0x00 };
	const unsigned char INSTRUMENT_CLARINET[24] PROGMEM = { 0x00, 0x32, 0x1D, 0xA2, 0x16, 0x04, 0x0A, 0x31, 0x08, 0x51, 0x26, 0x00, 0x00, 0x32, 0x45, 0xFE, 0x52, 0x04, 0x01, 0x31, 0x08, 0x55, 0x15, 0x00 };
	const unsigned char INSTRUMENT_PICCOLO[24]  PROGMEM = { 0x00, 0x24, 0x20, 0x67, 0xF6, 0x00, 0x00, 0xA2, 0x08, 0x65, 0x06, 0x00, 0x00, 0x24, 0x1C, 0x7F, 0x27, 0x00, 0x01, 0xA2, 0x08, 0x67, 0x06, 0x00 };
	const unsigned char INSTRUMENT_FLUTE1[24]   PROGMEM = { 0x00, 0x22, 0x26, 0x65, 0x66, 0x00, 0x00, 0xA1, 0x10, 0x67, 0x06, 0x00, 0x00, 0x02, 0x2A, 0xA2, 0x36, 0x00, 0x01, 0x21, 0x10, 0x6F, 0x06, 0x00 };
	const unsigned char INSTRUMENT_RECORDER[24] PROGMEM = { 0x00, 0x21, 0x11, 0x85, 0x66, 0x00, 0x00, 0x31, 0x1B, 0x68, 0x06, 0x00, 0x00, 0x32, 0x19, 0xD5, 0x39, 0x00, 0x01, 0x31, 0x08, 0x68, 0x06, 0x00 };
	const unsigned char INSTRUMENT_PANFLUTE[24] PROGMEM = { 0x00, 0x20, 0x00, 0x77, 0x08, 0x00, 0x0E, 0xA0, 0x15, 0x77, 0x58, 0x00, 0x00, 0x24, 0xD3, 0x76, 0xA9, 0x04, 0x01, 0x21, 0x08, 0x76, 0x08, 0x00 };
	const unsigned char INSTRUMENT_BOTTLEB[24]  PROGMEM = { 0x00, 0x2B, 0x12, 0x73, 0x68, 0x00, 0x0E, 0x26, 0x24, 0x67, 0x97, 0x00, 0x00, 0x22, 0x14, 0x66, 0x46, 0x00, 0x01, 0x21, 0x17, 0x60, 0xB6, 0x00 };
	const unsigned char INSTRUMENT_SHAKU[24]    PROGMEM = { 0x00, 0x61, 0x16, 0x67, 0x56, 0x02, 0x00, 0xA1, 0x11, 0x77, 0x06, 0x00, 0x00, 0x21, 0x15, 0xD7, 0x66, 0x02, 0x01, 0x01, 0x08, 0x40, 0xB6, 0x00 };
	const unsigned char INSTRUMENT_WHISTLE[24]  PROGMEM = { 0x00, 0x61, 0x31, 0xC4, 0x56, 0x02, 0x00, 0xA1, 0x08, 0x50, 0xB6, 0x00, 0x00, 0x61, 0x30, 0xC4, 0x66, 0x01, 0x01, 0x81, 0x08, 0x50, 0xB6, 0x00 };
	const unsigned char INSTRUMENT_OCARINA[24]  PROGMEM = { 0x00, 0x31, 0x2B, 0x57, 0x46, 0x04, 0x00, 0x31, 0x08, 0x68, 0x06, 0x00, 0x00, 0x32, 0x30, 0x47, 0x69, 0x04, 0x01, 0x31, 0x08, 0x68, 0x06, 0x00 };
	const unsigned char INSTRUMENT_SQUARWAV[24] PROGMEM = { 0x00, 0x21, 0x0D, 0xD4, 0x1B, 0x04, 0x01, 0x21, 0x0D, 0xC2, 0x26, 0x06, 0x00, 0x21, 0x15, 0xC6, 0x19, 0x04, 0x01, 0x21, 0x15, 0xD0, 0x27, 0x06 };
	const unsigned char INSTRUMENT_SAWWAV[24]   PROGMEM = { 0x00, 0x21, 0x11, 0xD4, 0x1B, 0x04, 0x00, 0x20, 0x08, 0xC2, 0x36, 0x03, 0x00, 0x21, 0x10, 0xC9, 0x49, 0x04, 0x01, 0x21, 0x08, 0xD0, 0x37, 0x01 };
	const unsigned char INSTRUMENT_SYNCALLI[24] PROGMEM = { 0x00, 0x22, 0x0E, 0x76, 0x66, 0x00, 0x06, 0xA1, 0x14, 0x67, 0x06, 0x00, 0x00, 0x22, 0x1E, 0x75, 0x06, 0x02, 0x01, 0x21, 0x14, 0x75, 0x06, 0x00 };
	const unsigned char INSTRUMENT_CHIFLEAD[24] PROGMEM = { 0x00, 0xD1, 0x00, 0xB7, 0x66, 0x02, 0x00, 0xA0, 0x08, 0x87, 0x06, 0x02, 0x00, 0x01, 0x14, 0x75, 0x66, 0x02, 0x01, 0x60, 0x08, 0xB5, 0x06, 0x02 };
	const unsigned char INSTRUMENT_CHARANG[24]  PROGMEM = { 0x00, 0x30, 0x0C, 0xF4, 0xA0, 0x00, 0x00, 0x22, 0x0C, 0x62, 0x0E, 0x00, 0x00, 0x20, 0x14, 0x77, 0x4E, 0x00, 0x01, 0x21, 0x0C, 0x90, 0x1C, 0x00 };
	const unsigned char INSTRUMENT_SOLOVOX[24]  PROGMEM = { 0x00, 0x20, 0x1A, 0x76, 0x64, 0x00, 0x06, 0x32, 0x0C, 0x47, 0x05, 0x00, 0x00, 0x31, 0x1B, 0x75, 0x03, 0x00, 0x01, 0x21, 0x0C, 0x75, 0x05, 0x00 };
	const unsigned char INSTRUMENT_FIFTHSAW[24] PROGMEM = { 0x00, 0x03, 0x0C, 0xF2, 0xA6, 0x00, 0x07, 0x06, 0x3F, 0xF0, 0xFB, 0x00, 0x00, 0x01, 0x15, 0xF0, 0xF8, 0x00, 0x00, 0x00, 0x14, 0xF3, 0xC8, 0x00 };
	const unsigned char INSTRUMENT_BASSLEAD[24] PROGMEM = { 0x00, 0x02, 0x0B, 0xF3, 0xFB, 0x01, 0x06, 0x21, 0x09, 0xF1, 0x2B, 0x01, 0x00, 0x01, 0xE1, 0xF3, 0xFB, 0x05, 0x01, 0x21, 0x10, 0xF0, 0x2B, 0x00 };
	const unsigned char INSTRUMENT_FANTASIA[24] PROGMEM = { 0x00, 0x12, 0xC0, 0xF2, 0x23, 0x00, 0x00, 0x12, 0x14, 0xE2, 0x55, 0x00, 0x00, 0x31, 0x1C, 0x69, 0x33, 0x02, 0x01, 0x30, 0x0D, 0x52, 0x15, 0x02 };
	const unsigned char INSTRUMENT_WARMPAD[24]  PROGMEM = { 0x00, 0x01, 0x18, 0x21, 0x53, 0x00, 0x00, 0x31, 0x08, 0x22, 0x55, 0x00, 0x00, 0x11, 0xD4, 0x21, 0x53, 0x01, 0x01, 0x31, 0x08, 0x21, 0x45, 0x00 };
	const unsigned char INSTRUMENT_POLYSYN[24]  PROGMEM = { 0x00, 0x20, 0x00, 0xC3, 0xF4, 0x02, 0x00, 0x01, 0x08, 0xF0, 0xF5, 0x00, 0x00, 0x01, 0x08, 0x32, 0x14, 0x05, 0x01, 0x21, 0x12, 0x20, 0x04, 0x00 };
	const unsigned char INSTRUMENT_SPACEVOX[24] PROGMEM = { 0x00, 0x30, 0xD1, 0xA2, 0x40, 0x00, 0x00, 0x20, 0x04, 0x63, 0x48, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
	const unsigned char INSTRUMENT_BOWEDGLS[24] PROGMEM = { 0x00, 0x06, 0x08, 0xF0, 0xE4, 0x00, 0x00, 0x21, 0x16, 0x45, 0x36, 0x00, 0x00, 0x01, 0x46, 0xE5, 0x34, 0x04, 0x01, 0x21, 0x0C, 0x40, 0x05, 0x00 };
	const unsigned char INSTRUMENT_METALPAD[24] PROGMEM = { 0x00, 0x21, 0x40, 0x63, 0x83, 0x00, 0x00, 0x21, 0x08, 0x30, 0x13, 0x00, 0x00, 0x21, 0x17, 0x63, 0xA3, 0x05, 0x01, 0x21, 0x09, 0x40, 0x13, 0x04 };
	const unsigned char INSTRUMENT_HALOPAD[24]  PROGMEM = { 0x00, 0x31, 0x08, 0x60, 0x15, 0x00, 0x05, 0x30, 0xC4, 0x64, 0xF8, 0x02, 0x00, 0x31, 0x14, 0xB0, 0xC5, 0x00, 0x01, 0x31, 0x0C, 0xD0, 0x45, 0x00 };
	const unsigned char INSTRUMENT_SWEEPPAD[24] PROGMEM = { 0x00, 0x31, 0x00, 0x44, 0xF4, 0x00, 0x05, 0x12, 0x8C, 0x12, 0xB3, 0x00, 0x00, 0x10, 0x10, 0x30, 0xB4, 0x01, 0x01, 0x30, 0x08, 0x74, 0x04, 0x01 };
	const unsigned char INSTRUMENT_ICERAIN[24]  PROGMEM = { 0x00, 0x08, 0xC0, 0xFB, 0x66, 0x00, 0x00, 0x83, 0x08, 0xF5, 0x68, 0x00, 0x00, 0x21, 0x14, 0xF0, 0x25, 0x00, 0x01, 0x21, 0x08, 0xDE, 0x05, 0x00 };
	const unsigned char INSTRUMENT_SOUNDTRK[24] PROGMEM = { 0x00, 0x08, 0x01, 0x33, 0xF2, 0x00, 0x00, 0x01, 0x17, 0x31, 0xF2, 0x00, 0x00, 0x01, 0x04, 0x31, 0xF2, 0x01, 0x01, 0x01, 0x08, 0x32, 0xF2, 0x00 };
	const unsigned char INSTRUMENT_CRYSTAL[24]  PROGMEM = { 0x00, 0x17, 0xC0, 0xF1, 0x31, 0x00, 0x08, 0x91, 0x08, 0xF1, 0x22, 0x00, 0x00, 0x95, 0x9B, 0xF1, 0x21, 0x00, 0x01, 0x91, 0x09, 0xF1, 0x23, 0x00 };
	const unsigned char INSTRUMENT_ATMOSPH[24]  PROGMEM = { 0x00, 0x01, 0x00, 0xD2, 0x24, 0x00, 0x00, 0x17, 0x0C, 0xD8, 0x34, 0x00, 0x00, 0x01, 0x17, 0xEA, 0x34, 0x02, 0x01, 0x20, 0x08, 0xE1, 0x14, 0x02 };
	const unsigned char INSTRUMENT_BRIGHT[24]   PROGMEM = { 0x00, 0x06, 0x08, 0xF0, 0xE4, 0x00, 0x00, 0x01, 0x08, 0xF5, 0x34, 0x00, 0x00, 0x01, 0x44, 0xE5, 0x34, 0x02, 0x01, 0xA0, 0x08, 0xE0, 0x44, 0x02 };
	const unsigned char INSTRUMENT_GOBLIN[24]   PROGMEM = { 0x00, 0x04, 0x02, 0x11, 0x32, 0x00, 0x08, 0x01, 0x08, 0x21, 0x22, 0x00, 0x00, 0x01, 0x41, 0x11, 0x24, 0x00, 0x01, 0x01, 0x08, 0x11, 0x23, 0x00 };
	const unsigned char INSTRUMENT_ECHODROP[24] PROGMEM = { 0x00, 0x05, 0xC0, 0xF8, 0xD3, 0x00, 0x00, 0x01, 0x0C, 0xE1, 0x03, 0x00, 0x00, 0x21, 0x10, 0x69, 0x33, 0x01, 0x01, 0x21, 0x08, 0x52, 0x13, 0x00 };
	const unsigned char INSTRUMENT_STARTHEM[24] PROGMEM = { 0x00, 0x02, 0x00, 0x83, 0xF3, 0x01, 0x06, 0x21, 0x08, 0x61, 0x23, 0x00, 0x00, 0x01, 0x0B, 0x73, 0xF3, 0x05, 0x01, 0x21, 0x08, 0x52, 0x23, 0x00 };
	const unsigned char INSTRUMENT_SITAR[24]    PROGMEM = { 0x00, 0x25, 0x12, 0xF7, 0x44, 0x04, 0x00, 0x01, 0x0F, 0xF8, 0x04, 0x04, 0x00, 0xA7, 0x17, 0x80, 0x64, 0x04, 0x01, 0x01, 0x10, 0xF3, 0x74, 0x04 };
	const unsigned char INSTRUMENT_BANJO[24]    PROGMEM = { 0x00, 0x01, 0x08, 0xF4, 0xA6, 0x04, 0x05, 0x05, 0x25, 0xF8, 0xFB, 0x00, 0x00, 0x01, 0x10, 0xF4, 0xFB, 0x00, 0x00, 0x02, 0x08, 0xF6, 0xC7, 0x04 };
	const unsigned char INSTRUMENT_SHAMISEN[24] PROGMEM = { 0x00, 0x04, 0x09, 0xFA, 0xA6, 0x00, 0x04, 0x07, 0x08, 0xF8, 0xFB, 0x00, 0x00, 0x01, 0x16, 0xF3, 0x95, 0x04, 0x01, 0x01, 0x08, 0xF3, 0xC5, 0x04 };
	const unsigned char INSTRUMENT_KOTO[24]     PROGMEM = { 0x00, 0x01, 0x08, 0xF4, 0xA4, 0x04, 0x05, 0x05, 0x25, 0xFA, 0xFB, 0x04, 0x00, 0x01, 0x18, 0xF4, 0xF5, 0x04, 0x00, 0x01, 0x08, 0xF3, 0xC5, 0x04 };
	const unsigned char INSTRUMENT_KALIMBA[24]  PROGMEM = { 0x00, 0x09, 0x00, 0xF8, 0x6E, 0x04, 0x00, 0x03, 0x08, 0xF8, 0x6E, 0x04, 0x00, 0x01, 0x00, 0xF4, 0x16, 0x00, 0x01, 0x86, 0x09, 0xF7, 0xEA, 0x00 };
	const unsigned char INSTRUMENT_BAGPIPE[24]  PROGMEM = { 0x00, 0x11, 0x0C, 0xD0, 0xF3, 0x00, 0x00, 0x32, 0x08, 0x80, 0x05, 0x00, 0x00, 0x31, 0xC9, 0x40, 0x09, 0x00, 0x01, 0x24, 0x0C, 0x50, 0x09, 0x04 };
	const unsigned char INSTRUMENT_FIDDLE[24]   PROGMEM = { 0x00, 0x24, 0xC9, 0xAA, 0x58, 0x04, 0x00, 0x20, 0x0C, 0x95, 0x08, 0x03, 0x00, 0x24, 0xC9, 0xC7, 0x88, 0x05, 0x01, 0x20, 0x08, 0x72, 0x28, 0x03 };
	const unsigned char INSTRUMENT_SHANNAI[24]  PROGMEM = { 0x00, 0x11, 0x0C, 0xD0, 0xF3, 0x00, 0x00, 0x32, 0x08, 0x80, 0x05, 0x00, 0x00, 0x31, 0xCC, 0x60, 0x06, 0x00, 0x01, 0x24, 0x0C, 0x60, 0x06, 0x04 };
	const unsigned char INSTRUMENT_TINKLBEL[24] PROGMEM = { 0x00, 0x16, 0x4F, 0xF6, 0x53, 0x00, 0x00, 0x19, 0x08, 0xF3, 0x53, 0x00, 0x00, 0x15, 0x41, 0xF1, 0x52, 0x06, 0x01, 0x14, 0x08, 0xF3, 0x52, 0x06 };
	const unsigned char INSTRUMENT_AGOGO[24]    PROGMEM = { 0x00, 0x17, 0x00, 0xFA, 0x57, 0x00, 0x00, 0x12, 0x08, 0xF5, 0x58, 0x00, 0x00, 0x14, 0x40, 0xF7, 0x52, 0x06, 0x01, 0x12, 0x08, 0xF5, 0x59, 0x06 };
	const unsigned char INSTRUMENT_STEELDRM[24] PROGMEM = { 0x00, 0x08, 0x1F, 0xC6, 0x37, 0x00, 0x06, 0x01, 0x08, 0x82, 0x95, 0x00, 0x00, 0x05, 0x0F, 0x65, 0x55, 0x00, 0x01, 0x11, 0x0F, 0x52, 0x75, 0x00 };
	const unsigned char INSTRUMENT_WOODBLOK[24] PROGMEM = { 0x00, 0x02, 0x09, 0xFC, 0xD6, 0x02, 0x00, 0x01, 0x08, 0xF7, 0xF7, 0x00, 0x00, 0x07, 0x3F, 0xFA, 0x4E, 0x00, 0x01, 0x03, 0xFF, 0xF5, 0xFE, 0x00 };
	const unsigned char INSTRUMENT_TAIKO[24]    PROGMEM = { 0x00, 0x1A, 0x00, 0xFB, 0x57, 0x00, 0x01, 0x30, 0x00, 0xF3, 0x54, 0x01, 0x00, 0x11, 0x48, 0xC5, 0x52, 0x01, 0x01, 0x10, 0x08, 0xC5, 0x57, 0x00 };
	const unsigned char INSTRUMENT_MELOTOM[24]  PROGMEM = { 0x00, 0x12, 0x01, 0xFB, 0xA7, 0x00, 0x00, 0x30, 0x08, 0xF3, 0x53, 0x00, 0x00, 0x10, 0xFF, 0xF4, 0x52, 0x00, 0x01, 0x10, 0x08, 0xC4, 0x57, 0x00 };
	const unsigned char INSTRUMENT_SYNDRUM[24]  PROGMEM = { 0x00, 0x2B, 0x00, 0xFF, 0x0E, 0x00, 0x0E, 0x0B, 0x08, 0xF7, 0xFE, 0x00, 0x00, 0x00, 0xC0, 0xF6, 0xFE, 0x02, 0x01, 0x20, 0x09, 0xFF, 0x0C, 0x00 };
	const unsigned char INSTRUMENT_REVRSCYM[24] PROGMEM = { 0x00, 0x2A, 0x00, 0xFF, 0x0E, 0x04, 0x0E, 0x0B, 0x08, 0x2F, 0x0E, 0x04, 0x00, 0x28, 0x00, 0xF9, 0x0E, 0x04, 0x01, 0x09, 0x08, 0x29, 0x0E, 0x04 };
	const unsigned char INSTRUMENT_FRETNOIS[24] PROGMEM = { 0x00, 0x0B, 0x00, 0x64, 0xF8, 0x04, 0x0E, 0x0B, 0x25, 0x77, 0xF8, 0x04, 0x00, 0x0B, 0x10, 0x56, 0xF8, 0x04, 0x01, 0x09, 0x08, 0x59, 0xE8, 0x04 };
	const unsigned char INSTRUMENT_BRTHNOIS[24] PROGMEM = { 0x00, 0x2B, 0x05, 0x79, 0x05, 0x00, 0x0E, 0x25, 0x08, 0x77, 0xA5, 0x00, 0x00, 0x26, 0x10, 0x66, 0xB9, 0x04, 0x01, 0x01, 0x0A, 0x76, 0xDE, 0x00 };
	const unsigned char INSTRUMENT_SEASHORE[24] PROGMEM = { 0x00, 0x30, 0x00, 0x11, 0x00, 0x00, 0x0E, 0x10, 0x08, 0x11, 0x32, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
	const unsigned char INSTRUMENT_BIRDS[24]    PROGMEM = { 0x00, 0x0A, 0x00, 0x59, 0xFE, 0x00, 0x01, 0x09, 0x00, 0x69, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
	const unsigned char INSTRUMENT_TELEPHON[24] PROGMEM = { 0x00, 0x0A, 0x0B, 0xE5, 0xF5, 0x05, 0x00, 0x02, 0x08, 0xE4, 0xF5, 0x00, 0x00, 0x08, 0x43, 0xF5, 0xF5, 0x03, 0x01, 0x02, 0x08, 0xF4, 0xF5, 0x00 };
	const unsigned char INSTRUMENT_HELICOPT[24] PROGMEM = { 0x00, 0x0B, 0x00, 0x82, 0xFA, 0x00, 0x0E, 0x04, 0x88, 0x77, 0xFA, 0x05, 0x00, 0x20, 0x11, 0xF7, 0xFA, 0x00, 0x01, 0x20, 0x1D, 0xFA, 0xFB, 0x00 };
	const unsigned char INSTRUMENT_APPLAUSE[24] PROGMEM = { 0x00, 0x2B, 0x00, 0xF0, 0x01, 0x00, 0x0E, 0x27, 0x08, 0x23, 0x13, 0x05, 0x00, 0x20, 0x7F, 0xFB, 0xE5, 0x00, 0x01, 0x20, 0x3F, 0xF4, 0xF5, 0x00 };
	const unsigned char INSTRUMENT_GUNSHOT[24]  PROGMEM = { 0x00, 0x0B, 0x40, 0xF5, 0x67, 0x00, 0x0E, 0x01, 0xC8, 0xF7, 0x64, 0x00, 0x00, 0x07, 0x3F, 0xF7, 0x34, 0x04, 0x01, 0x01, 0x00, 0xFA, 0x9E, 0x04 };


	// Instrument pointer array to access instruments by MIDI program.
	const unsigned char *midiInstruments[] = {
		INSTRUMENT_PIANO1,   INSTRUMENT_PIANO2,   INSTRUMENT_PIANO3,   INSTRUMENT_HONKTONK, INSTRUMENT_EP1,      INSTRUMENT_EP2,
		INSTRUMENT_HARPSIC,  INSTRUMENT_CLAVIC,   INSTRUMENT_CELESTA,  INSTRUMENT_GLOCK,    INSTRUMENT_MUSICBOX, INSTRUMENT_VIBES,
		INSTRUMENT_MARIMBA,  INSTRUMENT_XYLO,     INSTRUMENT_TUBEBELL, INSTRUMENT_SANTUR,   INSTRUMENT_ORGAN1,   INSTRUMENT_ORGAN2,
		INSTRUMENT_ORGAN3,   INSTRUMENT_PIPEORG,  INSTRUMENT_REEDORG,  INSTRUMENT_ACORDIAN, INSTRUMENT_HARMONIC, INSTRUMENT_BANDNEON,
		INSTRUMENT_NYLONGT,  INSTRUMENT_STEELGT,  INSTRUMENT_JAZZGT,   INSTRUMENT_CLEANGT,  INSTRUMENT_MUTEGT,   INSTRUMENT_OVERDGT,
		INSTRUMENT_DISTGT,   INSTRUMENT_GTHARMS,  INSTRUMENT_ACOUBASS, INSTRUMENT_FINGBASS, INSTRUMENT_PICKBASS, INSTRUMENT_FRETLESS,
		INSTRUMENT_SLAPBAS1, INSTRUMENT_SLAPBAS2, INSTRUMENT_SYNBASS1, INSTRUMENT_SYNBASS2, INSTRUMENT_VIOLIN,   INSTRUMENT_VIOLA,
		INSTRUMENT_CELLO,    INSTRUMENT_CONTRAB,  INSTRUMENT_TREMSTR,  INSTRUMENT_PIZZ,     INSTRUMENT_HARP,     INSTRUMENT_TIMPANI,
		INSTRUMENT_STRINGS,  INSTRUMENT_SLOWSTR,  INSTRUMENT_SYNSTR1,  INSTRUMENT_SYNSTR2,  INSTRUMENT_CHOIR,    INSTRUMENT_OOHS,
		INSTRUMENT_SYNVOX,   INSTRUMENT_ORCHIT,   INSTRUMENT_TRUMPET,  INSTRUMENT_TROMBONE, INSTRUMENT_TUBA,     INSTRUMENT_MUTETRP,
		INSTRUMENT_FRHORN,   INSTRUMENT_BRASS1,   INSTRUMENT_SYNBRAS1, INSTRUMENT_SYNBRAS2, INSTRUMENT_SOPSAX,   INSTRUMENT_ALTOSAX,
		INSTRUMENT_TENSAX,   INSTRUMENT_BARISAX,  INSTRUMENT_OBOE,     INSTRUMENT_ENGLHORN, INSTRUMENT_BASSOON,  INSTRUMENT_CLARINET,
		INSTRUMENT_PICCOLO,  INSTRUMENT_FLUTE1,   INSTRUMENT_RECORDER, INSTRUMENT_PANFLUTE, INSTRUMENT_BOTTLEB,  INSTRUMENT_SHAKU,
		INSTRUMENT_WHISTLE,  INSTRUMENT_OCARINA,  INSTRUMENT_SQUARWAV, INSTRUMENT_SAWWAV,   INSTRUMENT_SYNCALLI, INSTRUMENT_CHIFLEAD,
		INSTRUMENT_CHARANG,  INSTRUMENT_SOLOVOX,  INSTRUMENT_FIFTHSAW, INSTRUMENT_BASSLEAD, INSTRUMENT_FANTASIA, INSTRUMENT_WARMPAD,
		INSTRUMENT_POLYSYN,  INSTRUMENT_SPACEVOX, INSTRUMENT_BOWEDGLS, INSTRUMENT_METALPAD, INSTRUMENT_HALOPAD,  INSTRUMENT_SWEEPPAD,
		INSTRUMENT_ICERAIN,  INSTRUMENT_SOUNDTRK, INSTRUMENT_CRYSTAL,  INSTRUMENT_ATMOSPH,  INSTRUMENT_BRIGHT,   INSTRUMENT_GOBLIN,
		INSTRUMENT_ECHODROP, INSTRUMENT_STARTHEM, INSTRUMENT_SITAR,    INSTRUMENT_BANJO,    INSTRUMENT_SHAMISEN, INSTRUMENT_KOTO,
		INSTRUMENT_KALIMBA,  INSTRUMENT_BAGPIPE,  INSTRUMENT_FIDDLE,   INSTRUMENT_SHANNAI,  INSTRUMENT_TINKLBEL, INSTRUMENT_AGOGO,
		INSTRUMENT_STEELDRM, INSTRUMENT_WOODBLOK, INSTRUMENT_TAIKO,    INSTRUMENT_MELOTOM,  INSTRUMENT_SYNDRUM,  INSTRUMENT_REVRSCYM,
		INSTRUMENT_FRETNOIS, INSTRUMENT_BRTHNOIS, INSTRUMENT_SEASHORE, INSTRUMENT_BIRDS,    INSTRUMENT_TELEPHON, INSTRUMENT_HELICOPT,
		INSTRUMENT_APPLAUSE, INSTRUMENT_GUNSHOT
	};

#endif
